@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,9 +26,7 @@ class QDomDocument;
 class QFile;
 class KArchiveDirectory;
 
-namespace PimCommon
-{
-
+namespace PimCommon {
 class ImportLibreOfficeAutocorrection : public ImportAbstractAutocorrection
 {
 public:
@@ -48,10 +46,9 @@ private:
     void closeArchive();
     bool loadDomElement(QDomDocument &doc, QFile *file);
     bool importFile(Type type, const KArchiveDirectory *archiveDirectory);
-    KZip *mArchive;
-    QTemporaryDir *mTempDir;
+    KZip *mArchive = nullptr;
+    QTemporaryDir *mTempDir = nullptr;
 };
-
 }
 
 #endif // IMPORTLIBREOFFICEAUTOCORRECTION_H
