@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,8 +24,7 @@
 
 #include <QTextEdit>
 
-namespace PimCommon
-{
+namespace PimCommon {
 class AutoCorrection;
 class AutoCorrectionWidget;
 class LineEditWithAutoCorrection;
@@ -42,7 +41,7 @@ private Q_SLOTS:
     void slotSaveSettings();
 
 private:
-    PimCommon::AutoCorrectionWidget *mWidget;
+    PimCommon::AutoCorrectionWidget *mWidget = nullptr;
 };
 
 class TextEditAutoCorrectionWidget : public QTextEdit
@@ -56,7 +55,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    PimCommon::AutoCorrection *mAutoCorrection;
+    PimCommon::AutoCorrection *mAutoCorrection = nullptr;
 };
 
 class AutocorrectionTestWidget : public QWidget
@@ -71,9 +70,9 @@ private Q_SLOTS:
     void slotChangeMode(bool);
 
 private:
-    TextEditAutoCorrectionWidget *mEdit;
-    PimCommon::LineEditWithAutoCorrection *mSubject;
-    PimCommon::AutoCorrection *mAutoCorrection;
+    TextEditAutoCorrectionWidget *mEdit = nullptr;
+    PimCommon::LineEditWithAutoCorrection *mSubject = nullptr;
+    PimCommon::AutoCorrection *mAutoCorrection = nullptr;
     KSharedConfig::Ptr mConfig;
 };
 
