@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,6 @@
 #include "templatemanager.h"
 #include "templatewidgets/templatelistwidget.h"
 
-
 #include <KDirWatch>
 
 #include <KConfigGroup>
@@ -32,22 +31,14 @@ using namespace PimCommon;
 class PimCommon::TemplateManagerPrivate
 {
 public:
-    TemplateManagerPrivate()
-        : mTemplateListWidget(nullptr),
-          mDirWatch(nullptr)
-    {
-
-    }
-
     QStringList mTemplatesDirectories;
-    PimCommon::TemplateListWidget *mTemplateListWidget;
-    KDirWatch *mDirWatch;
+    PimCommon::TemplateListWidget *mTemplateListWidget = nullptr;
+    KDirWatch *mDirWatch = nullptr;
 };
 
 TemplateManager::TemplateManager(const QString &relativeTemplateDir, PimCommon::TemplateListWidget *templateListWidget)
-    : QObject(templateListWidget),
-      d(new PimCommon::TemplateManagerPrivate)
-
+    : QObject(templateListWidget)
+    , d(new PimCommon::TemplateManagerPrivate)
 {
     d->mTemplateListWidget = templateListWidget;
     d->mDirWatch = new KDirWatch(this);
@@ -127,5 +118,3 @@ TemplateInfo TemplateManager::loadTemplate(const QString &themePath, const QStri
     }
     return info;
 }
-
-#include "moc_templatemanager.cpp"
