@@ -4,7 +4,7 @@
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2001 Marc Mutz <mutz@kde.org>
 
-    Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -31,8 +31,8 @@
     your version.
 */
 
-#ifndef _SIMPLESTRINGLISTEDITOR_H_
-#define _SIMPLESTRINGLISTEDITOR_H_
+#ifndef SIMPLESTRINGLISTEDITOR_H
+#define SIMPLESTRINGLISTEDITOR_H
 
 #include <QWidget>
 #include <QStringList>
@@ -47,8 +47,7 @@ class QListWidgetItem;
 // SimpleStringListEditor (a listbox with "add..." and "remove" buttons)
 //
 //
-namespace PimCommon
-{
+namespace PimCommon {
 class SimpleStringListEditorPrivate;
 class PIMCOMMON_EXPORT SimpleStringListEditor : public QWidget
 {
@@ -66,12 +65,8 @@ public:
     };
 
     /** Constructor. Populates the list with @p strings. */
-    explicit SimpleStringListEditor(QWidget *parent = nullptr,
-                                    ButtonCode buttons = Unsorted,
-                                    const QString &addLabel = QString(),
-                                    const QString &removeLabel = QString(),
-                                    const QString &modifyLabel = QString(),
-                                    const QString &addDialogLabel = QString());
+    explicit SimpleStringListEditor(QWidget *parent = nullptr, ButtonCode buttons = Unsorted, const QString &addLabel = QString(),
+                                    const QString &removeLabel = QString(), const QString &modifyLabel = QString(), const QString &addDialogLabel = QString());
 
     ~SimpleStringListEditor();
     /** Sets the list of strings displayed to @p strings */
@@ -111,15 +106,13 @@ protected Q_SLOTS:
     void slotDown();
 
     void slotSelectionChanged();
-private Q_SLOTS:
-    void slotContextMenu(const QPoint &);
 
 private:
+    void slotContextMenu(const QPoint &);
     bool containsString(const QString &str);
     QList<QListWidgetItem *> selectedItems() const;
     SimpleStringListEditorPrivate *const d;
 };
-
 }
 
-#endif // _SIMPLESTRINGLISTEDITOR_H_
+#endif // SIMPLESTRINGLISTEDITOR_H
