@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,8 +25,7 @@
 class KActionCollection;
 class QAction;
 class KXMLGUIClient;
-namespace PimCommon
-{
+namespace PimCommon {
 class PluginInterfacePrivate;
 class PIMCOMMONAKONADI_EXPORT PluginInterface : public QObject
 {
